*****************************************;
** SAS Scoring Code for PROC Logistic;
*****************************************;

length I_BAD $ 12;
label I_BAD = 'Into: BAD' ;
label U_BAD = 'Unnormalized Into: BAD' ;

label P_BAD1 = 'Predicted: BAD=1' ;
label P_BAD0 = 'Predicted: BAD=0' ;

drop _LMR_BAD;
_LMR_BAD=0;

*** Check DEROG for missing values;
if missing(DEROG) then do;
   _LMR_BAD=1;
   goto _SKIP_000;
end;

*** Check DELINQ for missing values;
if missing(DELINQ) then do;
   _LMR_BAD=1;
   goto _SKIP_000;
end;

*** Check CLAGE for missing values;
if missing(CLAGE) then do;
   _LMR_BAD=1;
   goto _SKIP_000;
end;

*** Check NINQ for missing values;
if missing(NINQ) then do;
   _LMR_BAD=1;
   goto _SKIP_000;
end;

*** Check CLNO for missing values;
if missing(CLNO) then do;
   _LMR_BAD=1;
   goto _SKIP_000;
end;

*** Check DEBTINC for missing values;
if missing(DEBTINC) then do;
   _LMR_BAD=1;
   goto _SKIP_000;
end;

*** Generate design variables for JOB;
drop _2_0 _2_1 _2_2 _2_3 _2_4 ;
length _st7 $ 7; drop _st7;
_st7 = left(trim(put (JOB, $7.)));
_2_0= 0; 
_2_1= 0; 
_2_2= 0; 
_2_3= 0; 
_2_4= 0; 
_dm_find = 0; drop _dm_find;
if _st7 <= 'Other'  then do;
   if _st7 <= 'Office'  then do;
      if _st7 = 'Mgr'  then do;
         _2_0 = 1;
         _dm_find = 1;
      end;
      else do;
         if _st7 = 'Office'  then do;
            _2_1 = 1;
            _dm_find = 1;
         end;
      end;
   end;
   else do;
      if _st7 = 'Other'  then do;
         _2_2 = 1;
         _dm_find = 1;
      end;
   end;
end;
else do;
   if _st7 <= 'Sales'  then do;
      if _st7 = 'ProfExe'  then do;
         _2_3 = 1;
         _dm_find = 1;
      end;
      else do;
         if _st7 = 'Sales'  then do;
            _2_4 = 1;
            _dm_find = 1;
         end;
      end;
   end;
   else do;
      if _st7 = 'Self'  then do;
         _2_0= -1; 
         _2_1= -1; 
         _2_2= -1; 
         _2_3= -1; 
         _2_4= -1; 
         _dm_find = 1;
      end;
   end;
end;
if not _dm_find then do;
   _2_0 = .;
   _2_1 = .;
   _2_2 = .;
   _2_3 = .;
   _2_4 = .;
   _LMR_BAD=1;
   goto _SKIP_000;
end;

*** Compute Linear Predictors;
drop _LP0;
_LP0 = 0;

*** Effect: JOB;
_TEMP = 1;
_LP0 = _LP0 + (-0.24107398075096) * _TEMP * _2_0;
_LP0 = _LP0 + (-0.79580369036356) * _TEMP * _2_1;
_LP0 = _LP0 + (-0.25736379669747) * _TEMP * _2_2;
_LP0 = _LP0 + (-0.27226992250569) * _TEMP * _2_3;
_LP0 = _LP0 + (1.19974783121864) * _TEMP * _2_4;
_LP0 = _LP0 + (0.7213099212492) * DEROG;
_LP0 = _LP0 + (0.75844040406507) * DELINQ;
_LP0 = _LP0 + (-0.0057374547498) * CLAGE;
_LP0 = _LP0 + (0.11994428288648) * NINQ;
_LP0 = _LP0 + (-0.02043048597114) * CLNO;
_LP0 = _LP0 + (0.09962427903575) * DEBTINC;

*** Predicted values;
drop _MAXP _IY _P0 _P1;
_TEMP = -4.91329909198729  + _LP0;
if (_TEMP < 0) then do;
   _TEMP = exp(_TEMP);
   _P0 = _TEMP / (1 + _TEMP);
end;
else _P0 = 1 / (1 + exp(-_TEMP));
_P1 = 1.0 - _P0;
P_BAD1 = _P0;
_MAXP = _P0;
_IY = 1;
P_BAD0 = _P1;
if (_P1 >  _MAXP + 1E-8) then do;
   _MAXP = _P1;
   _IY = 2;
end;
select( _IY );
   when (1) do;
      I_BAD = '1' ;
      U_BAD = 1;
   end;
   when (2) do;
      I_BAD = '0' ;
      U_BAD = 0;
   end;
   otherwise do;
      I_BAD = '';
      U_BAD = .;
   end;
end;
_SKIP_000:
if _LMR_BAD = 1 then do;
I_BAD = '';
U_BAD = .;
P_BAD1 = .;
P_BAD0 = .;
end;
drop _TEMP;
